@@ -1,5 +1,6 @@
 ## Read in data from the MED64 array.
-
+## This reader was started early 2011, but no data yet available so
+## have not pursued.
 ## ~/proj/carmen/med64/read_med.R
 
 ## model on the sql reader.
@@ -16,7 +17,7 @@ med64.spike.reader <- function(file, sep=300) {
                  ylim=c(0,8)*sep,
                  spacing=sep,
                  pos=pos)
-  
+  distbreaks <- NULL
   res <- list(layout=layout, spikes=spikes, distbreaks=distbreaks)
 
 }
