@@ -16,7 +16,7 @@ plot.mm.s <- function(s, whichcells=NULL,
                       label.cells = FALSE,
                       use.names=TRUE,
                       show.bursts = FALSE,
-                      main=NULL, ylab='Channel',
+                      main=NULL, ylab='Unit',
                       xlab="Time (s)",
                       for.figure=FALSE,
                       show.episodes,
@@ -738,7 +738,7 @@ hist.make.labels <- function(tmin, tmax, nbins, right=TRUE) {
   breaks <- seq(from=tmin, to=tmax, length=nbins+1)
   dig.lab <- 3
   for (dig in dig.lab:12) {
-    ch.br <- formatC(breaks, dig = dig, wid = 1)
+    ch.br <- formatC(breaks, digits = dig, width = 1)
     if (ok <- all(ch.br[-1] != ch.br[-(nbins+1)])) 
       break
   }
@@ -2295,7 +2295,7 @@ plot.mealayout.1 <- function(x, use.names=FALSE, ...) {
   plot(NA, asp=1,
        xlim=x$xlim, ylim=x$ylim,
        bty="n",
-       xlab="spacing (µm)", ylab="", type="n")
+       xlab="spacing (\u00b5m)", ylab="", type="n")
   if (use.names)
     text(pos[,1], pos[,2], rownames(pos), ...)
   else
@@ -2308,7 +2308,7 @@ plot.mealayout.hi <- function(x, use.names=FALSE, ...) {
   plot(pos, asp=1,
        xlim=x$xlim, ylim=x$ylim,
        bty="n",
-       xlab="spacing (µm)", ylab="", pch=20)
+       xlab="spacing (\u00b5m)", ylab="", pch=20)
 }
 
 spikes.to.ragged.csv <- function(spikes, filename='test.csv') {
